"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MedicationEntryField = void 0;

var _preact = require("preact");

var _fetchDrugAutocomplete = require("./utils/fetch-drug-autocomplete");

var _formFields = require("./form-fields");

var _autoCompleteInput = require("./auto-complete-input");

var _selectedItem = require("./selected-item");

var _createId = require("./utils/create-id");

class MedicationEntryField extends _preact.Component {
  componentDidUpdate(prevProps, prevState) {
    const term = this.state.term;

    if (term && term !== prevState.term) {
      this.setState({
        loading: true
      });
      (0, _fetchDrugAutocomplete.fetchDrugAutocomplete)(term).then(results => {
        if (term === this.state.term) {
          const toSet = {
            ["term_".concat(term)]: results,
            loading: false
          };
          this.setState(toSet);
        }
      });
    }
  }

  drugSelected(drug) {
    const {
      updateValue
    } = this.props;
    updateValue(drug);
    this.setState({
      term: '',
      ["term_".concat(this.state.term)]: undefined
    });
  }

  focusOnInput() {
    const input = this.base.querySelector('input');

    if (input) {
      input.focus();
    }
  }

  render({
    item,
    updateValue,
    className
  }) {
    const drugName = item.value && item.value.name;
    return (0, _preact.h)("div", {
      className: className
    }, (0, _preact.h)(_formFields.Label, {
      item: item,
      updateValue: updateValue
    }), !drugName && (0, _preact.h)(_autoCompleteInput.AutoCompleteInput, {
      item: item,
      doSearch: _fetchDrugAutocomplete.fetchDrugAutocomplete,
      renderEntry: entry => entry.name,
      selectCallback: entry => this.drugSelected(entry),
      renderNoMatches: searchString => (0, _preact.h)("span", null, "no match found for \"", searchString, "\"", ' ', (0, _preact.h)("span", {
        className: "gray i"
      }, "push \"enter\" to add anyway")),
      selectNoMatch: searchString => {
        updateValue({
          id: (0, _createId.createId)('unknown'),
          name: searchString
        });
      }
    }), drugName && (0, _preact.h)(_selectedItem.SelectedItem, {
      key: drugName,
      label: drugName,
      onClose: e => {
        e.preventDefault();
        updateValue('');
        setTimeout(() => this.focusOnInput(), 200);
      }
    }));
  }

}

exports.MedicationEntryField = MedicationEntryField;