"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MultiMedicationEntryField = void 0;

var _preact = require("preact");

var _fetchDrugAutocomplete = require("./utils/fetch-drug-autocomplete");

var _formFields = require("./form-fields");

var _selectedItem = require("./selected-item");

var _autoCompleteInput = require("./auto-complete-input");

var _createId = require("./utils/create-id");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class MultiMedicationEntryField extends _preact.Component {
  constructor(props) {
    super(props);
    this.focusOnInput = this.focusOnInput.bind(this);

    this.focusOnInputDelayed = () => setTimeout(this.focusOnInput, 200);

    this.addDrug = this.addDrug.bind(this);
  }

  isEmptyArray(arr) {
    return Array.isArray(arr) && !arr.length;
  }

  focusOnInput() {
    const input = this.base && this.base.querySelector('input');

    if (input) {
      input.focus();
    }
  }

  addDrug(drug) {
    const {
      item,
      updateValue
    } = this.props;
    const {
      value
    } = item;
    const valueIsEmptyArray = typeof value === 'string';
    const drugs = value && !valueIsEmptyArray ? value : [];
    const copy = drugs.slice();
    copy.push(drug);
    updateValue(copy);
    this.focusOnInput();
  }

  render() {
    const {
      item,
      updateValue
    } = this.props;
    const {
      value
    } = item;
    const valueIsEmptyArray = this.isEmptyArray(value);
    const itemCopy = Object.assign({}, item);
    delete itemCopy.subLabel;
    const modifiedItemForLabel = !value ? _objectSpread(_objectSpread({}, item), {}, {
      buttons: [['none', []]]
    }) : item;
    return (0, _preact.h)("div", null, (0, _preact.h)(_formFields.Label, {
      item: modifiedItemForLabel,
      updateValue: updateValue
    }), !valueIsEmptyArray && (0, _preact.h)(_autoCompleteInput.AutoCompleteInput, {
      item: modifiedItemForLabel,
      doSearch: _fetchDrugAutocomplete.fetchDrugAutocomplete,
      renderEntry: entry => entry.name,
      selectCallback: this.addDrug,
      renderNoMatches: searchString => (0, _preact.h)("span", null, "no match found for \"", searchString, "\"", ' ', (0, _preact.h)("span", {
        className: "gray i"
      }, "push \"enter\" to add anyway")),
      selectNoMatch: searchString => {
        this.addDrug({
          id: (0, _createId.createId)('unknown'),
          name: searchString
        });
      }
    }), (0, _preact.h)("div", {
      className: "mb2"
    }, valueIsEmptyArray && (0, _preact.h)(_selectedItem.SelectedItem, {
      key: "none",
      label: "none",
      onClose: e => {
        e.preventDefault();
        updateValue(null);
        this.focusOnInputDelayed();
      }
    }), value && !valueIsEmptyArray && value.length !== 0 && (0, _preact.h)("div", null, (0, _preact.h)("div", {
      className: "mb2 fw3 f6 pt2"
    }, "Chosen Medications:"), (0, _preact.h)("div", {
      className: "flex flex-wrap gap2"
    }, value.map(drug => (0, _preact.h)(_selectedItem.SelectedItem, {
      key: drug.name,
      label: drug.name,
      onClose: e => {
        e.preventDefault();
        const newVal = value.filter(item => item.id !== drug.id);
        updateValue(this.isEmptyArray(newVal) ? null : newVal);
        this.focusOnInputDelayed();
      }
    }))))));
  }

}

exports.MultiMedicationEntryField = MultiMedicationEntryField;